{% verbatim %}
<script id="calculator-row-tmpl" type="text/x-handlebars-template">
<li class="form-group clearfix gp-calculator-row">
    <fieldset>
    <legend class="sr-only">{{ trans "calculator_legend" }}</legend>
    <span class="col-xs-4 gp-calc-percentage">
        <input type="text" id="calculator-percentage-{{ id }}" name="calculator-percentage" value="{{ percentage }}" class="form-control gp-calc-input-percentage" required />
        <label for="calculator-percentage-{{ id }}" class="calculator-err">
            <span class="sr-only">{{# if is_last}}{{ trans "calculator_perc_label_lower" }}{{else}}{{# if is_first}}{{ trans "calculator_perc_label_upper" }}{{else}}{{ trans "calculator_perc_label" }}{{/if}}{{/if}}</span>
            <span class="pull-left gp-calc-err"></span>
        </label>
    </span><span class="gp-percent-sign" aria-hidden="true">%</span>
    <span class="gp-calc-equals" aria-hidden="true">=</span>
    <span class="col-xs-4 gp-calc-grade">
        <input type="text" id="calculator-grade-{{ id }}" name="calculator-grade" value="{{ grade }}" class="form-control gp-calc-input" required />
        <label for="calculator-grade-{{ id }}" class="calculator-err">
            <span class="sr-only">{{# if is_last}}{{ trans "calculator_grade_label_lower" }}{{else}}{{# if is_first}}{{ trans "calculator_grade_label_upper" }}{{else}}{{ trans "calculator_grade_label" }}{{/if}}{{/if}}</span>
            <span class="pull-right gp-calc-err"></span>
        </label>
    </span>
    </fieldset>
</li>
</script>
{% endverbatim %}
